/* pqmarble.h generated by valac 0.56.13, the Vala compiler, do not modify */

#ifndef __SRC_PQMARBLE_H__
#define __SRC_PQMARBLE_H__

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gio/gio.h>
#include <gtk/gtk.h>
#include <gdk/gdk.h>

G_BEGIN_DECLS

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define PQ_MARBLE_TYPE_SETTINGS (pq_marble_settings_get_type ())
#define PQ_MARBLE_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PQ_MARBLE_TYPE_SETTINGS, PQMarbleSettings))
#define PQ_MARBLE_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PQ_MARBLE_TYPE_SETTINGS, PQMarbleSettingsClass))
#define PQ_MARBLE_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PQ_MARBLE_TYPE_SETTINGS))
#define PQ_MARBLE_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PQ_MARBLE_TYPE_SETTINGS))
#define PQ_MARBLE_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PQ_MARBLE_TYPE_SETTINGS, PQMarbleSettingsClass))

typedef struct _PQMarbleSettings PQMarbleSettings;
typedef struct _PQMarbleSettingsClass PQMarbleSettingsClass;
typedef struct _PQMarbleSettingsPrivate PQMarbleSettingsPrivate;

struct _PQMarbleSettings {
	GObject parent_instance;
	PQMarbleSettingsPrivate * priv;
};

struct _PQMarbleSettingsClass {
	GObjectClass parent_class;
};

VALA_EXTERN GType pq_marble_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (PQMarbleSettings, g_object_unref)
VALA_EXTERN PQMarbleSettings* pq_marble_settings_construct (GType object_type,
                                                const gchar* path);
VALA_EXTERN GSettings* pq_marble_settings_get_schema (PQMarbleSettings* self);
VALA_EXTERN void pq_marble_settings_set_schema (PQMarbleSettings* self,
                                    GSettings* value);
VALA_EXTERN GtkCssProvider* pq_marble_get_css_provider_for_data (const gchar* data);
VALA_EXTERN void pq_marble_set_theming_for_data (GtkWidget* widget,
                                     const gchar* data,
                                     const gchar* class_name,
                                     gint priority);
VALA_EXTERN void pq_marble_add_css_provider_from_resource (const gchar* resource,
                                               gint priority,
                                               GdkDisplay* display);

G_END_DECLS

#endif
